pub enum TryFromValueError {
TypeMismatch,
OutOfBounds,
}Expand description
Errors that may occur upon converting a Value to a primitive type.
Variants
TypeMismatch
The type does not match the expected type.
OutOfBounds
The value is out of bounds for the expected type.