pub enum LinkerError {
DuplicateDefinition {
import_name: ImportName,
import_item: Extern,
},
CannotFindDefinitionForImport {
name: ImportName,
item_type: ExternType,
},
FuncTypeMismatch {
name: ImportName,
expected: FuncType,
actual: FuncType,
},
Table(TableError),
Memory(MemoryError),
GlobalTypeMismatch {
name: ImportName,
expected: GlobalType,
actual: GlobalType,
},
}Expand description
An error that may occur upon operating with Linker instances.
Variants
DuplicateDefinition
Encountered duplicate definitions for the same name.
Fields
import_name: ImportNameThe duplicate import name of the definition.
CannotFindDefinitionForImport
Encountered when no definition for an import is found.
Fields
name: ImportNameThe name of the import for which no definition was found.
item_type: ExternTypeThe type of the import for which no definition has been found.
FuncTypeMismatch
Encountered when a function signature does not match the expected signature.
Fields
name: ImportNameThe name of the import with the mismatched type.
Table(TableError)
Occurs when an imported table does not satisfy the required table type.
Memory(MemoryError)
Occurs when an imported memory does not satisfy the required memory type.
GlobalTypeMismatch
Encountered when an imported global variable has a mismatching global variable type.
Fields
name: ImportNameThe name of the import with the mismatched type.
expected: GlobalTypeThe expected global variable type.
actual: GlobalTypeThe actual global variable type found.
Implementations
Sourceimpl LinkerError
impl LinkerError
Sourcepub fn cannot_find_definition_of_import(import: &ImportType<'_>) -> Self
pub fn cannot_find_definition_of_import(import: &ImportType<'_>) -> Self
Creates a new LinkerError for when an imported definition was not found.